pub enum VoteInstruction {
InitializeAccount(VoteInit),
Authorize(Pubkey, VoteAuthorize),
Vote(Vote),
Withdraw(u64),
UpdateValidatorIdentity,
UpdateCommission(u8),
VoteSwitch(Vote, Hash),
AuthorizeChecked(VoteAuthorize),
}Variants
InitializeAccount(VoteInit)
Initialize a vote account
Account references
[WRITE]Uninitialized vote account[]Rent sysvar[]Clock sysvar[SIGNER]New validator identity (node_pubkey)
Authorize(Pubkey, VoteAuthorize)
Authorize a key to send votes or issue a withdrawal
Account references
[WRITE]Vote account to be updated with the Pubkey for authorization[]Clock sysvar[SIGNER]Vote or withdraw authority
Vote(Vote)
A Vote instruction with recent votes
Account references
[WRITE]Vote account to vote with[]Slot hashes sysvar[]Clock sysvar[SIGNER]Vote authority
Withdraw(u64)
Withdraw some amount of funds
Account references
[WRITE]Vote account to withdraw from[WRITE]Recipient account[SIGNER]Withdraw authority
UpdateValidatorIdentity
Update the vote account’s validator identity (node_pubkey)
Account references
[WRITE]Vote account to be updated with the given authority public key[SIGNER]New validator identity (node_pubkey)[SIGNER]Withdraw authority
UpdateCommission(u8)
Update the commission for the vote account
Account references
[WRITE]Vote account to be updated[SIGNER]Withdraw authority
VoteSwitch(Vote, Hash)
A Vote instruction with recent votes
Account references
[WRITE]Vote account to vote with[]Slot hashes sysvar[]Clock sysvar[SIGNER]Vote authority
AuthorizeChecked(VoteAuthorize)
Authorize a key to send votes or issue a withdrawal
This instruction behaves like Authorize with the additional requirement that the new vote
or withdraw authority must also be a signer.
Account references
[WRITE]Vote account to be updated with the Pubkey for authorization[]Clock sysvar[SIGNER]Vote or withdraw authority[SIGNER]New vote or withdraw authority